@@ -217,7 +217,6 @@ class GenomeCov(object):
             chromosome can be analysed one by one. Used by the sequana_coverage
             standalone. The only advantage is to speed up the constructor creation
             and could also be used by the Snakemake implementation.
-
         """
         # Keep information if the genome is circular and the window size used
         self._circular = None
@@ -237,18 +236,6 @@ class GenomeCov(object):
 
         self.input_filename = input_filename
 
-        """
-        # check if the input is a csv of a previous analysis
-        try:
-            self.chr_list = None
-            self._read_csv(input_filename)
-            self.positions = {}
-            #for chrom in self.chrom_names:
-            #self.positions[chrom] = {"start":start "end":end "N": N}
-        except FileNotFoundError as e:
-            print("FileNotFound error({0}): {1}".format(e.errno, e.strerror))
-            sys.exit(1)
-        """
         if high_threshold < 2.5 and self.force is False:
             raise ValueError("high threshold must be >=2.5")
         if low_threshold > -2.5 and self.force is False:
@@ -426,13 +413,13 @@ class GenomeCov(object):
     """
     def _read_csv(self, input_filename):
         # set regex to get important information about previous analysis
-        re_threshold = re.compile("thresholds:([\d,\.-]+)")
-        re_window_size = re.compile("\swindow_size:(\d+)")
-        re_circular = re.compile("circular:(\w+)")
-        re_gc_window_size = re.compile("gc_window_size:(\d+)")
-        re_genbank = re.compile("genbank:([\{0}\w\.\-]+)".format(os.sep))
-        re_chrom = re.compile("^# ([\w\-\.]+):")
-        re_gaussian = re.compile("(\[\{.+\}\])")
+        re_threshold = re.compile(r"thresholds:([\d,\.-]+)")
+        re_window_size = re.compile(r"\swindow_size:(\d+)")
+        re_circular = re.compile(r"circular:(\w+)")
+        re_gc_window_size = re.compile(r"gc_window_size:(\d+)")
+        re_genbank = re.compile(r"genbank:([\{0}\w\.\-]+)".format(os.sep))
+        re_chrom = re.compile(r"^# ([\w\-\.]+):")
+        re_gaussian = re.compile(r"(\[\{.+\}\])")
 
         with open(input_filename, "r") as fp:
             line = fp.readline()
@@ -541,7 +528,7 @@ class GenomeCov(object):
         """ Write all data in a csv.
 
         :param str output_filename: csv output file name.
-        :param **dict kwargs: parameters of :meth:`pandas.DataFrame.to_csv`.
+        :param dict kwargs: parameters of :meth:`pandas.DataFrame.to_csv`.
         """
         # Concatenate all df
         df_list = [chrom.df for chrom in self.chr_list]
