@@ -655,7 +655,10 @@ class KrakenResults(object):
         # to simplify, if this is the case, we will just take the first read
         # length for now. 
         df = self.df.copy()
-        df.length = df.length.apply(lambda x: int(x.split("|")[0]))
+        try: # kraken2
+            df.length = df.length.apply(lambda x: int(x.split("|")[0]))
+        except:
+            pass
         df[["status", "length"]].groupby('status').boxplot()
         return df
 
@@ -1239,14 +1242,19 @@ class KrakenSequential(object):
         total = 0
         classified = 0
         for f_temp, db in zip(self._list_kraken_output, self.databases):
-            df = pd.read_csv(f_temp, sep="\t", header=None,usecols=[0])
-            C = sum(df[0] == "C")
-            total += C
-            classified += C
-            U = sum(df[0] == "U")
-            total+=U
             # In theory, the first N-1 DB returns only classified (C) read
             # and the last one contains both
+            try:            
+                df = pd.read_csv(f_temp, sep="\t", header=None,usecols=[0])
+                C = sum(df[0] == "C")
+                U = sum(df[0] == "U")
+            except pd.errors.EmptyDataError:
+                # if no read classified, 
+                C = 0
+                U = 0
+            total+=U
+            total += C
+            classified += C
             summary[db.name] = {"C":C}
             if U != 0: # the last one
                 summary['unclassified'] = U
@@ -1553,7 +1561,7 @@ class MultiKrakenResults():
             pylab.xlabel("Percentage (%)", fontsize=fontsize)
             pylab.ylabel("Sample index/name", fontsize=fontsize)
             if len(self.sample_names)<max_labels:
-                pylab.yticks(range(len(self.sample_names)), self.sample_names, 
+                pylab.yticks(range(len(self.sample_names)), self.sample_names[::-1], 
                     fontsize=ytick_fontsize)
             else:
                 pylab.yticks([1], [""])
@@ -1564,7 +1572,7 @@ class MultiKrakenResults():
             pylab.xlabel("Sample index/name", fontsize=fontsize)
             pylab.ylim([0, 100])
             if len(self.sample_names)<max_labels:
-                pylab.xticks(range(len(self.sample_names)), self.sample_names, 
+                pylab.xticks(range(len(self.sample_names)), self.sample_names[::-1], 
                     fontsize=ytick_fontsize)
             else:
                 pylab.xticks([1], [""])
@@ -1599,8 +1607,6 @@ class MultiKrakenResults2():
         else:
             self.sample_names = sample_names
 
-
-
     def get_df(self, limit=5, sorting_method="sample_name"):
         import pandas as pd
         import json
@@ -1668,7 +1674,7 @@ class MultiKrakenResults2():
         pylab.xlabel("Percentage (%)", fontsize=fontsize)
         pylab.ylabel("Sample index/name", fontsize=fontsize)
         if len(self.sample_names)<max_labels:
-            pylab.yticks(range(len(self.sample_names)), df.index[::-1], 
+            pylab.yticks(range(len(self.sample_names)), df.index, 
                 fontsize=ytick_fontsize)
         else:
             pylab.yticks([1], [""])
